Moogli
======

.. image:: https://travis-ci.org/aviralg/moogli.svg?branch=master
    :target: https://travis-ci.org/aviralg/moogli
    :alt: Build Status

.. image:: https://readthedocs.org/projects/moogli/badge/?version=latest
    :target: https://readthedocs.org/projects/moogli/?badge=latest
    :alt: Documentation Status

.. image:: https://pypip.in/v/moogli/badge.png
    :target: https://pypi.python.org/pypi/moogli/
    :alt: Latest PyPI version

.. image:: https://pypip.in/download/moogli/badge.svg?period=day
    :target: https://pypi.python.org/pypi/moogli/
    :alt: Daily Downloads

.. image:: https://pypip.in/download/moogli/badge.svg?period=week
    :target: https://pypi.python.org/pypi/moogli/
    :alt: Weekly Downloads

.. image:: https://pypip.in/download/moogli/badge.svg?period=month
    :target: https://pypi.python.org/pypi/moogli/
    :alt: Monthly Downloads

.. image:: https://img.shields.io/badge/license-GPLv2-red.svg
    :target: http://www.gnu.org/licenses/gpl-2.0.html
    :alt: GPLv2 License

.. image:: https://d2weczhvl823v0.cloudfront.net/aviralg/moogli/trend.png
    :target: https://bitdeli.com/free
    :alt: Bitdeli Badge


Moogli is a 3D neuronal network activity visualizer. It can show neuronal network morphologies and visualize electrical and chemical activity from compartmental modeling simulations. It is platform agnostic and completely based on open source tools and libraries. Feel free to download, use and fork it.
